PyTaskState

Trait PyTaskState 

pub trait PyTaskState:
    Default
    + Clone
    + Debug
    + Serialize
    + DeserializeOwned
    + Reflect
    + TypePath
    + GetTypeRegistration
    + Typed { }
State carried across invocations of a PyTask.

The state must be serializable because both backends turn it into an owned, mutable Python value on every process(...) call and then deserialize the result back into Rust.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors